==> beigesoft-webcrud-jar-1.1.5-src.tar.bz2: src/main/java/org/beigesoft/web/servlet/WServicePublic.java <==
package org.beigesoft.web.servlet;

/*
 * Copyright (c) 2017 Beigesoft ™
 *
 * Licensed under the GNU General Public License (GPL), Version 2.0
 * (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html
 */

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.RequestDispatcher;

import org.beigesoft.log.ILogger;
import org.beigesoft.service.ISrvI18n;
import org.beigesoft.web.service.UtlJsp;
import org.beigesoft.web.model.HttpRequestData;
import org.beigesoft.handler.IHandlerRequest;
import org.beigesoft.factory.IFactoryAppBeans;
import org.beigesoft.exception.ExceptionWithCode;
import org.beigesoft.delegate.IDelegateExc;
import org.beigesoft.delegate.IDelegateEvaluate;
import org.beigesoft.web.model.FactoryAndServlet;

/**
 * <p>Generic servlet that delegate request to a
 * IHandlerRequest that can implements any business logic
 * e.g. report, form edit, entities list, etc.
 * This is public service, so it checks whether user request public.
 * For example webstore requests for buyers are public, but webstore-admin
 * and webstore-seseller requests are secured.
 * </p>
 *
 * @author Yury Demidenko
 */
@SuppressWarnings("serial")
public class WServicePublic extends HttpServlet {

  /**
   * <p>App beans factory.</p>
   **/
  private IFactoryAppBeans factoryAppBeans;

  /**
   * <p>Folder for redirected JSP, e.g. "JSP WEB-INF/jsp/".
   * Settled through init params.</p>
   **/
  private String dirJsp;

  @Override
  public final void init() throws ServletException {
    this.dirJsp = getInitParameter("dirJsp");
    try {
      this.factoryAppBeans = (IFactoryAppBeans) getServletContext()
        .getAttribute("IFactoryAppBeans");
      if (this.factoryAppBeans == null) {
        String factoryAppBeansClass = getInitParameter("factoryAppBeansClass");
        Object factoryObject = Class.forName(factoryAppBeansClass)
          .newInstance();
        this.factoryAppBeans = (IFactoryAppBeans) factoryObject;
        getServletContext().setAttribute("IFactoryAppBeans",
          this.factoryAppBeans);
        String initFactoryClass = getInitParameter("initFactoryClass");
        Object initFactoryObject = Class.forName(initFactoryClass)
          .newInstance();
        @SuppressWarnings("unchecked")
        IDelegateExc<FactoryAndServlet> initFactory =
          (IDelegateExc<FactoryAndServlet>) initFactoryObject;
        initFactory.makeWith(new FactoryAndServlet(this.factoryAppBeans, this));
      }
    } catch (Exception e) {
      if (this.factoryAppBeans != null) {
        ILogger logger = null;
        try {
          logger = (ILogger) this.factoryAppBeans.lazyGet("ILogger");
        } catch (Exception e1) {
          e1.printStackTrace();
        }
        if (logger != null) {
          logger.error(null, getClass(), "INIT", e);
        }
      }
      throw new ServletException(e);
    }
  }

  @Override
  public final void doGet(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    doWork(pReq, pResp);
  }

  @Override
  public final void doPost(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    doWork(pReq, pResp);
  }


  /**
   * <p>Generic request handler.</p>
   * @param pReq Http Servlet Request
   * @param pResp Http Servlet Response
   * @throws ServletException ServletException
   * @throws IOException IOException
   **/
  public final void doWork(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    pReq.setCharacterEncoding("UTF-8");
    pResp.setCharacterEncoding("UTF-8");
    try {
      // for self-registration as public service:
      String nameHandler = pReq.getParameter("nmHnd");
      IHandlerRequest srvHandleRequest = (IHandlerRequest) this
        .factoryAppBeans.lazyGet(nameHandler);
      @SuppressWarnings("unchecked")
      IDelegateEvaluate<HttpServletRequest, Boolean> checkerPublic =
        (IDelegateEvaluate<HttpServletRequest, Boolean>) this.factoryAppBeans
          .lazyGet("checkerPublic");
      if (!checkerPublic.evaluate(pReq)) {
        throw new ExceptionWithCode(ExceptionWithCode.FORBIDDEN,
          "not_public_request");
      }
      HttpRequestData requestData = new HttpRequestData(pReq, pResp);
      srvHandleRequest.handle(requestData);
      ISrvI18n srvI18n = (ISrvI18n) this.factoryAppBeans.lazyGet("ISrvI18n");
      UtlJsp utlJsp = (UtlJsp) this.factoryAppBeans.lazyGet("UtlJsp");
      pReq.setAttribute("srvI18n", srvI18n);
      pReq.setAttribute("utlJsp", utlJsp);
      String nmRnd = pReq.getParameter("nmRnd");
      String path = dirJsp + nmRnd + ".jsp";
      RequestDispatcher rd = getServletContext().getRequestDispatcher(path);
      rd.include(pReq, pResp);
    } catch (Exception e) {
      if (this.factoryAppBeans != null) {
        ILogger logger = null;
        try {
          logger = (ILogger) this.factoryAppBeans.lazyGet("ILogger");
        } catch (Exception e1) {
          e1.printStackTrace();
        }
        if (logger != null) {
          logger.error(null, getClass(), "WORK", e);
        } else {
          e.printStackTrace();
        }
      } else {
        e.printStackTrace();
      }
      if (e instanceof ExceptionWithCode) {
        pReq.setAttribute("error_code",
          ((ExceptionWithCode) e).getCode());
        pReq.setAttribute("short_message",
          ((ExceptionWithCode) e).getShortMessage());
      } else {
        pReq.setAttribute("error_code",
          HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      }
      pReq.setAttribute("javax.servlet.error.status_code",
        HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      pReq.setAttribute("javax.servlet.error.exception", e);
      pReq.setAttribute("javax.servlet.error.request_uri",
        pReq.getRequestURI());
      pReq.setAttribute("javax.servlet.error.servlet_name", this.getClass()
        .getCanonicalName());
      pResp.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
    }
  }

  //Simple getters and setters:
  /**
   * <p>Geter for factoryAppBeans.</p>
   * @return IFactoryAppBeans
   **/
  public final IFactoryAppBeans getFactoryAppBeans() {
    return this.factoryAppBeans;
  }

  /**
   * <p>Setter for factoryAppBeans.</p>
   * @param pFactoryAppBeans reference
   **/
  public final void setFactoryAppBeans(
    final IFactoryAppBeans pFactoryAppBeans) {
    this.factoryAppBeans = pFactoryAppBeans;
  }

  /**
   * <p>Geter for dirJsp.</p>
   * @return String
   **/
  public final String getDirJsp() {
    return this.dirJsp;
  }

  /**
   * <p>Setter for dirJsp.</p>
   * @param pDirJsp reference
   **/
  public final void setDirJsp(final String pDirJsp) {
    this.dirJsp = pDirJsp;
  }
}

==> beigesoft-webcrud-jar-1.1.7-src.tar.bz2: src/main/java/org/beigesoft/web/servlet/WServicePublic.java <==
package org.beigesoft.web.servlet;

/*
 * Copyright (c) 2017 Beigesoft ™
 *
 * Licensed under the GNU General Public License (GPL), Version 2.0
 * (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html
 */

import java.util.HashMap;
import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.RequestDispatcher;

import org.beigesoft.log.ILogger;
import org.beigesoft.service.ISrvI18n;
import org.beigesoft.web.service.UtlJsp;
import org.beigesoft.web.model.HttpRequestData;
import org.beigesoft.handler.IHandlerRequest;
import org.beigesoft.factory.IFactoryAppBeans;
import org.beigesoft.exception.ExceptionWithCode;
import org.beigesoft.delegate.IDelegateExc;
import org.beigesoft.delegate.IDelegateEvaluate;
import org.beigesoft.web.model.FactoryAndServlet;

/**
 * <p>Generic servlet that delegate request to a
 * IHandlerRequest that can implements any business logic
 * e.g. report, form edit, entities list, etc.
 * This is public service, so it checks whether user request public.
 * For example webstore requests for buyers are public, but webstore-admin
 * and webstore-seseller requests are secured.
 * </p>
 *
 * @author Yury Demidenko
 */
@SuppressWarnings("serial")
public class WServicePublic extends HttpServlet {

  /**
   * <p>App beans factory.</p>
   **/
  private IFactoryAppBeans factoryAppBeans;

  /**
   * <p>Folder for redirected JSP, e.g. "JSP WEB-INF/jsp/".
   * Settled through init params.</p>
   **/
  private String dirJsp;

  @Override
  public final void init() throws ServletException {
    this.dirJsp = getInitParameter("dirJsp");
    try {
      this.factoryAppBeans = (IFactoryAppBeans) getServletContext()
        .getAttribute("IFactoryAppBeans");
      if (this.factoryAppBeans == null) {
        String factoryAppBeansClass = getInitParameter("factoryAppBeansClass");
        Object factoryObject = Class.forName(factoryAppBeansClass)
          .newInstance();
        this.factoryAppBeans = (IFactoryAppBeans) factoryObject;
        getServletContext().setAttribute("IFactoryAppBeans",
          this.factoryAppBeans);
        String initFactoryClass = getInitParameter("initFactoryClass");
        Object initFactoryObject = Class.forName(initFactoryClass)
          .newInstance();
        @SuppressWarnings("unchecked")
        IDelegateExc<FactoryAndServlet> initFactory =
          (IDelegateExc<FactoryAndServlet>) initFactoryObject;
        initFactory.makeWith(new FactoryAndServlet(this.factoryAppBeans, this));
      }
    } catch (Exception e) {
      if (this.factoryAppBeans != null) {
        ILogger logger = null;
        try {
          logger = (ILogger) this.factoryAppBeans.lazyGet("ILogger");
        } catch (Exception e1) {
          e1.printStackTrace();
        }
        if (logger != null) {
          logger.error(null, getClass(), "INIT", e);
        }
      }
      throw new ServletException(e);
    }
  }

  @Override
  public final void doGet(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    doWork(pReq, pResp);
  }

  @Override
  public final void doPost(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    doWork(pReq, pResp);
  }


  /**
   * <p>Generic request handler.</p>
   * @param pReq Http Servlet Request
   * @param pResp Http Servlet Response
   * @throws ServletException ServletException
   * @throws IOException IOException
   **/
  public final void doWork(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    pReq.setCharacterEncoding("UTF-8");
    pResp.setCharacterEncoding("UTF-8");
    try {
      HashMap<String, Object> reqVars = new HashMap<String, Object>();
      // for self-registration as public service:
      String nameHandler = pReq.getParameter("nmHnd");
      IHandlerRequest srvHandleRequest = (IHandlerRequest) this
        .factoryAppBeans.lazyGet(nameHandler);
      @SuppressWarnings("unchecked")
      IDelegateEvaluate<HttpServletRequest, Boolean> checkerPublic =
        (IDelegateEvaluate<HttpServletRequest, Boolean>) this.factoryAppBeans
          .lazyGet("checkerPublic");
      if (!checkerPublic.evaluate(pReq)) {
        throw new ExceptionWithCode(ExceptionWithCode.FORBIDDEN,
          "not_public_request");
      }
      HttpRequestData requestData = new HttpRequestData(pReq, pResp);
      requestData.setAttribute("reqVars", reqVars);
      IHandlerRequest hndlI18nRequest = (IHandlerRequest) this
        .factoryAppBeans.lazyGet("hndlI18nRequest");
      hndlI18nRequest.handle(reqVars, requestData);
      srvHandleRequest.handle(reqVars, requestData);
      ISrvI18n srvI18n = (ISrvI18n) this.factoryAppBeans.lazyGet("ISrvI18n");
      UtlJsp utlJsp = (UtlJsp) this.factoryAppBeans.lazyGet("UtlJsp");
      pReq.setAttribute("srvI18n", srvI18n);
      pReq.setAttribute("utlJsp", utlJsp);
      String nmRnd = pReq.getParameter("nmRnd");
      String path = dirJsp + nmRnd + ".jsp";
      RequestDispatcher rd = getServletContext().getRequestDispatcher(path);
      rd.include(pReq, pResp);
    } catch (Exception e) {
      if (this.factoryAppBeans != null) {
        ILogger logger = null;
        try {
          logger = (ILogger) this.factoryAppBeans.lazyGet("ILogger");
        } catch (Exception e1) {
          e1.printStackTrace();
        }
        if (logger != null) {
          logger.error(null, getClass(), "WORK", e);
        } else {
          e.printStackTrace();
        }
      } else {
        e.printStackTrace();
      }
      if (e instanceof ExceptionWithCode) {
        pReq.setAttribute("error_code",
          ((ExceptionWithCode) e).getCode());
        pReq.setAttribute("short_message",
          ((ExceptionWithCode) e).getShortMessage());
      } else {
        pReq.setAttribute("error_code",
          HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      }
      pReq.setAttribute("javax.servlet.error.status_code",
        HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      pReq.setAttribute("javax.servlet.error.exception", e);
      pReq.setAttribute("javax.servlet.error.request_uri",
        pReq.getRequestURI());
      pReq.setAttribute("javax.servlet.error.servlet_name", this.getClass()
        .getCanonicalName());
      pResp.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
    }
  }

  //Simple getters and setters:
  /**
   * <p>Geter for factoryAppBeans.</p>
   * @return IFactoryAppBeans
   **/
  public final IFactoryAppBeans getFactoryAppBeans() {
    return this.factoryAppBeans;
  }

  /**
   * <p>Setter for factoryAppBeans.</p>
   * @param pFactoryAppBeans reference
   **/
  public final void setFactoryAppBeans(
    final IFactoryAppBeans pFactoryAppBeans) {
    this.factoryAppBeans = pFactoryAppBeans;
  }

  /**
   * <p>Geter for dirJsp.</p>
   * @return String
   **/
  public final String getDirJsp() {
    return this.dirJsp;
  }

  /**
   * <p>Setter for dirJsp.</p>
   * @param pDirJsp reference
   **/
  public final void setDirJsp(final String pDirJsp) {
    this.dirJsp = pDirJsp;
  }
}
